@@ -337,8 +337,7 @@
   # Return the results in an object of the type list.
   for (i in 2L:9) {
     suppressMessages(RANGE <- which(diffQ == fct(diffQ[(i + 1):(N - i)]))) 
-    if (class(try(na.omit(xQ[(RANGE - i):(RANGE + i)]), 
-                  silent = T)) == "try-error") {
+    if (as.character(class(try(na.omit(xQ[(RANGE - i):(RANGE + i)]), silent = T))) == "try-error") {
       list.res[[i-1]] <- NA
     } else {
       limits.xQ <- na.omit(xQ[(RANGE - i):(RANGE + i)])
